import React from 'react';
import { Meta } from '@storybook/react';
import { SemSubstrVisComponent } from './semanticsubstratesvis';
import { graphQueryResultSlice, querybuilderSlice, schemaSlice, visualizationSlice } from '../../../data-access/store';
import { configureStore } from '@reduxjs/toolkit';
import { Provider } from 'react-redux';
import {
  big2ndChamberQueryResult,
  gotCharacter2Character,
  mockRecommendationsActorMovie,
  marieBoucherSampleSchemaRaw,
  big2ndChamberSchemaRaw,
} from '../../../mock-data';
import { graphQueryBackend2graphQuery } from '@graphpolaris/shared/lib/data-access/store/graphQueryResultSlice';

const Mockstore = configureStore({
  reducer: {
    schema: schemaSlice.reducer,
    graphQueryResult: graphQueryResultSlice.reducer,
    visualize: visualizationSlice.reducer,
    querybuilder: querybuilderSlice.reducer,
  },
});

const Component: Meta<typeof SemSubstrVisComponent.component> = {
  title: 'Visualizations/SemanticSubstrates',
  component: SemSubstrVisComponent.component,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <div
          style={{
            width: '100%',
            height: '100vh',
          }}
        >
          {story()}
        </div>
      </Provider>
    ),
  ],
};

export const TestWithBig2ndChamber = {
  args: {
    data: graphQueryBackend2graphQuery(big2ndChamberQueryResult),
    configuration: SemSubstrVisComponent.configuration,
  },
};

export const TestWithRecommendationsActorMovie = {
  args: {
    data: graphQueryBackend2graphQuery(mockRecommendationsActorMovie),
    configuration: SemSubstrVisComponent.configuration,
  },
};

export const TestWithGOTcharacter2character = {
  args: {
    data: graphQueryBackend2graphQuery(gotCharacter2Character),
    configuration: SemSubstrVisComponent.configuration,
  },
};

export default Component;
